from colorama import Fore, Back, Style                                                                         
                                                                                                                
class Colors:                                                                                                  
    PRIMARY = Fore.CYAN                                                                                        
    SECONDARY = Fore.MAGENTA                                                                                   
    SUCCESS = Fore.GREEN                                                                                       
    ERROR = Fore.RED                                                                                           
    WARNING = Fore.YELLOW                                                                                      
    RESET = Style.RESET_ALL 