OPENAI_MODELS = [
    "gpt-4o",
    "chatgpt-4o-latest",
    "gpt-4o-mini",
    "o1",
    "o1-mini",
    "o1-preview"
]

ANTHROPIC_MODELS = [
    "claude-3-5-sonnet-20241022",
    "claude-3-haiku-20240307"
]

GEMINI_MODELS = [
    "gemini-2.0-flash-exp",
    "gemini-1.5-pro"
]
